# GetPaymentRunDataTransactionElementResponseStatus

The status of the newly generated payment.  **Note:** This field is only available if `type` is `Payment`. 

## Enum

* `PROCESSED` (value: `'Processed'`)

* `PROCESSING` (value: `'Processing'`)

* `ERROR` (value: `'Error'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


